package com.flyer.foster.controller;

import cn.dev33.satoken.annotation.SaCheckLogin;
import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.flyer.foster.dto.*;
import com.flyer.foster.entity.PosterLib;
import com.flyer.foster.entity.Whisper;
import com.flyer.foster.service.IPosterLibService;
import com.flyer.foster.service.IWhisperService;
import com.flyer.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 悄悄话
 *
 * @author flyer
 * @since 2024-05-09
 */
@RestController
@RequestMapping("/admin/whisper")
public class WhisperController {
    @Autowired
    private IWhisperService iWhisperService;

    /**
     * 悄悄话列表-分页
     *
     * @param current 当前页
     * @param size    当前页显示条数
     * @return
     */
    @GetMapping("/list/{current}/{size}")
    public R getPageList(@PathVariable Integer current, @PathVariable Integer size, WhisperQueryDTO queryDTO) {
        return R.ok().result(iWhisperService.getPageList(new Page<>(current, size), queryDTO));
    }

    /**
     * 新增悄悄话
     *
     * @return
     */
    @PostMapping("")
    public R addPosterLib(@Valid @RequestBody WhisperAddDTO addDTO) {
        Whisper whisper = new Whisper();
        BeanUtil.copyProperties(addDTO, whisper);
        return R.ok().result(iWhisperService.save(whisper));
    }

    /**
     * 修改悄悄话
     */
    @PutMapping("")
    public R updatePosterLib(@Valid @RequestBody WhisperUpdateDTO updateDTO) {
        return R.ok().result(
                iWhisperService.lambdaUpdate()
                        .set(Whisper::getContent, updateDTO.getContent())
                        .set(StrUtil.isNotBlank(updateDTO.getStartTime()), Whisper::getStartTime, updateDTO.getStartTime())
                        .set(StrUtil.isNotBlank(updateDTO.getEndTime()), Whisper::getEndTime, updateDTO.getEndTime())
                        .eq(Whisper::getId, updateDTO.getId())
                        .update());
    }

    /**
     * 批量删除
     *
     * @param idList
     * @return
     */
    @PostMapping("/delete")
    public R deletePosterLib(@RequestBody List<Integer> idList) {
        return R.ok().result(iWhisperService.deleteByIdList(idList));
    }
}
